@@ -10,7 +10,9 @@ import publication
 
 import aws_cdk.core._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-detective", "1.49.0", __name__[0:-6], "aws-detective@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-detective", "1.53.0", __name__[0:-6], "aws-detective@1.53.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
